Class: Fog::Hyperv::Compute::IntegrationServices

Inherits:
Fog::Hyperv::Collection show all
Defined in:
lib/fog/hyperv/compute/models/integration_services.rb

Overview

Note:

Requires a vm_id to be specified, as integration services are not retrievable as loose objects

A collection of integration services available for a VM

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Fog::Hyperv::Collection

#all, get_method, #initialize, #new, requires, requires?

Constructor Details

This class inherits a constructor from Fog::Hyperv::Collection

Instance Attribute Details

#computer_nameString

Returns the name of the computer running the VM that these COM ports are attached to.

Returns:

  • (String)

    the name of the computer running the VM that these COM ports are attached to



17
# File 'lib/fog/hyperv/compute/models/integration_services.rb', line 17

attribute :computer_name

#vm_idString

Returns the GUID of the VM containing the COM ports.

Returns:

  • (String)

    the GUID of the VM containing the COM ports



14
# File 'lib/fog/hyperv/compute/models/integration_services.rb', line 14

attribute :vm_id

Instance Method Details

#get(name, **filters) ⇒ Object

Get an integration service by name

Parameters:

  • id (String)

    the name of the integration service to retrieve

Raises:

  • (ArgumentError)


23
24
25
26
27
# File 'lib/fog/hyperv/compute/models/integration_services.rb', line 23

def get(name, **filters)
  raise ArgumentError, 'Must provide a name' if name.nil? || name.empty?

  super(name: name, **filters)
end