Class: Fog::Hyperv::Compute::IntegrationServices
- Inherits:
-
Fog::Hyperv::Collection
- Object
- Collection
- Fog::Hyperv::Collection
- Fog::Hyperv::Compute::IntegrationServices
- Defined in:
- lib/fog/hyperv/compute/models/integration_services.rb
Overview
Note:
Requires a vm_id to be specified, as integration services are not retrievable as loose objects
A collection of integration services available for a VM
Instance Attribute Summary collapse
-
#computer_name ⇒ String
The name of the computer running the VM that these COM ports are attached to.
-
#vm_id ⇒ String
The GUID of the VM containing the COM ports.
Instance Method Summary collapse
-
#get(name, **filters) ⇒ Object
Get an integration service by name.
Methods inherited from Fog::Hyperv::Collection
#all, get_method, #initialize, #new, requires, requires?
Constructor Details
This class inherits a constructor from Fog::Hyperv::Collection
Instance Attribute Details
#computer_name ⇒ String
Returns the name of the computer running the VM that these COM ports are attached to.
17 |
# File 'lib/fog/hyperv/compute/models/integration_services.rb', line 17 attribute :computer_name |
#vm_id ⇒ String
Returns the GUID of the VM containing the COM ports.
14 |
# File 'lib/fog/hyperv/compute/models/integration_services.rb', line 14 attribute :vm_id |
Instance Method Details
#get(name, **filters) ⇒ Object
Get an integration service by name
23 24 25 26 27 |
# File 'lib/fog/hyperv/compute/models/integration_services.rb', line 23 def get(name, **filters) raise ArgumentError, 'Must provide a name' if name.nil? || name.empty? super(name: name, **filters) end |